==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pt_BR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Tipo de arquivo MIME",
    "is" : "é",
    "is not" : "não é",
    "matches" : "coincide",
    "does not match" : "não coincide",
    "Example: {placeholder}" : "Examplo: {placeholder}",
    "File name" : "Nome do arquivo",
    "File size (upload)" : "Tamanho do arquivo (envio)",
    "less" : "menos",
    "less or equals" : "menores ou iguais",
    "greater or equals" : "maiores ou iguais",
    "greater" : "maior",
    "File system tag" : "Etiqueta do sistema de arquivos",
    "is tagged with" : "está etiquetado com",
    "is not tagged with" : "não está etiquetado com",
    "Select tag…" : "Selecionar etiqueta...",
    "Request remote address" : "Solicitar endereço remoto",
    "matches IPv4" : "IPv4 coincide",
    "does not match IPv4" : "IPV4 não coincide",
    "matches IPv6" : "IPV6 coincide",
    "does not match IPv6" : "IPV6 não coincide",
    "Request time" : "Tempo de solicitação",
    "between" : "entre",
    "not between" : "não entre",
    "Start" : "Iniciar",
    "End" : "Fim",
    "Select timezone…" : "Selecionar fuso horário...",
    "Request URL" : "Solicitação de URL",
    "Predefined URLs" : "URLs predefinidas",
    "Files WebDAV" : "Arquivos WebDAV",
    "Request user agent" : "Solicitar usuário agente",
    "Sync clients" : "Sincronizar clientes",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de Desktop",
    "Thunderbird & Outlook addons" : "Extensões para Thunderbird & Outlook",
    "User group membership" : "Adesão de grupo de usuário",
    "is member of" : "é membro de",
    "is not member of" : "não é membro de",
    "Short rule description" : "Descrição curta da regra",
    "Add rule" : "Adicionar regra",
    "Reset" : "Redefinir",
    "Save" : "Salvar",
    "Saving…" : "Salvando...",
    "Group list is empty" : "Lista de grupos vazia",
    "Unable to retrieve the group list" : "Impossível recuperar a lista do grupo",
    "Saved" : "Salvo",
    "Saving failed:" : "A gravação falhou:",
    "Add rule group" : "Adicionar regra do grupo",
    "The given operator is invalid" : "O operador fornecido é inválido",
    "The given regular expression is invalid" : "A expressão regular fornecida é inválida",
    "The given file size is invalid" : "O tamanho fornecido do arquivo é inválido",
    "The given tag id is invalid" : "O id da etiqueta fornecida é inválido",
    "The given IP range is invalid" : "O intervalo de IP fornecido é inválido",
    "The given IP range is not valid for IPv4" : "O intervalo de IP fornecido é inválido para IPv4",
    "The given IP range is not valid for IPv6" : "O range de IP fornecido é inválido para IPv6",
    "The given time span is invalid" : "O intervalo de tempo fornecido é inválido",
    "The given start time is invalid" : "O horário de início fornecido é inválido",
    "The given end time is invalid" : "O horário de término fornecido é inválido",
    "The given group does not exist" : "O grupo fornecido não existe",
    "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
    "Operation #%s does not exist" : "Operação #%s não existe",
    "Operation %s does not exist" : "Operação %s não existe",
    "Operation %s is invalid" : "Operação %s é inválida",
    "Check %s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid" : "Verifique se %s é inválido",
    "Check #%s does not exist" : "Verifique se %s não existe",
    "Tag management" : "Gerenciamento de rótulos",
    "Files workflow engine" : "Sistema de fluxo de trabalho de arquivos",
    "Open documentation" : "Abrir documentação",
    "Loading…" : "Carregando...",
    "Workflow" : "Fluxo de trabalho"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pt_BR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador fornecido é inválido",
    "The given regular expression is invalid" : "A expressão regular fornecida é inválida",
    "The given file size is invalid" : "O tamanho fornecido do arquivo é inválido",
    "The given tag id is invalid" : "O id da etiqueta fornecida é inválido",
    "The given IP range is invalid" : "O intervalo de IP fornecido é inválido",
    "The given IP range is not valid for IPv4" : "O intervalo de IP fornecido é inválido para IPv4",
    "The given IP range is not valid for IPv6" : "O range de IP fornecido é inválido para IPv6",
    "The given time span is invalid" : "O intervalo de tempo fornecido é inválido",
    "The given start time is invalid" : "O horário de início fornecido é inválido",
    "The given end time is invalid" : "O horário de término fornecido é inválido",
    "The given group does not exist" : "O grupo fornecido não existe",
    "File" : "Arquivo",
    "File created" : "Arquivo criado",
    "File updated" : "Arquivo atualizado",
    "File renamed" : "Arquivo renomeado",
    "File deleted" : "Arquivo excluído",
    "File accessed" : "Arquivo acessado",
    "File copied" : "Arquivo copiado",
    "Tag assigned" : "Rótulo atribuído",
    "Operation #%s does not exist" : "Operação #%s não existe",
    "Entity %s does not exist" : "Entidade %s não existe",
    "Entity %s is invalid" : "Entidade %s é inválida",
    "No events are chosen." : "Nenhum evento escolhido.",
    "Entity %s has no event %s" : "Entidade %s não tem evento %s",
    "Operation %s does not exist" : "Operação %s não existe",
    "Operation %s is invalid" : "Operação %s é inválida",
    "Check %s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid" : "Verifique se %s é inválido",
    "Check %s is not allowed with this entity" : "Verificação de %s não é permitida nesta entidade",
    "Check #%s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
    "Workflows" : "Fluxo de Trabalho",
    "Nextcloud workflow engine" : "Mecanismo de fluxo de trabalho Nextcloud",
    "Select a filter" : "Selecionar um filtro",
    "Select a comparator" : "Selecionar um comparador",
    "Select a file type" : "Selecionar um tipo de arquivo",
    "e.g. httpd/unix-directory" : "por ex. httpd/unix-directory",
    "Images" : "Imagens",
    "Office documents" : "Documentos Office",
    "PDF documents" : "Documentos PDF",
    "Custom mimetype" : "Mimetype personalizado",
    "Select a tag" : "Selecione um rótulo",
    "No results" : "Nenhum resultado",
    "%s (invisible)" : "%s (invisível)",
    "%s (restricted)" : "%s (restrito)",
    "Please enter a valid time span" : "Digite um período de tempo válido",
    "Select a request URL" : "Selecione uma URL de solicitação",
    "Predefined URLs" : "URLs predefinidas",
    "Files WebDAV" : "Arquivos WebDAV",
    "Others" : "Outros",
    "Custom URL" : "URL personalizada",
    "Select a user agent" : "Selecione um agente de usuário",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de Desktop",
    "Thunderbird & Outlook addons" : "Extensões para Thunderbird & Outlook",
    "Custom user agent" : "Agente do usuário personalizado",
    "When" : "Quando",
    "and" : "e",
    "Cancel" : "Cancelar",
    "Delete" : "Excluir",
    "The configuration is invalid" : "A configuração é inválida",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar mais",
    "File name" : "Nome do arquivo",
    "is" : "é",
    "is not" : "não é",
    "matches" : "coincide",
    "does not match" : "não coincide",
    "File MIME type" : "Tipo de arquivo MIME",
    "File size (upload)" : "Tamanho do arquivo (envio)",
    "less" : "menos",
    "less or equals" : "menores ou iguais",
    "greater or equals" : "maiores ou iguais",
    "greater" : "maior",
    "Request remote address" : "Solicitar endereço remoto",
    "matches IPv4" : "IPv4 coincide",
    "does not match IPv4" : "IPV4 não coincide",
    "matches IPv6" : "IPV6 coincide",
    "does not match IPv6" : "IPV6 não coincide",
    "File system tag" : "Etiqueta do sistema de arquivos",
    "is tagged with" : "está etiquetado com",
    "is not tagged with" : "não está etiquetado com",
    "Request URL" : "Solicitação de URL",
    "Request time" : "Tempo de solicitação",
    "between" : "entre",
    "not between" : "não entre",
    "Request user agent" : "Solicitar usuário agente",
    "User group membership" : "Adesão de grupo de usuário",
    "is member of" : "é membro de",
    "is not member of" : "não é membro de",
    "Short rule description" : "Descrição curta da regra",
    "Add rule" : "Adicionar regra",
    "Reset" : "Redefinir",
    "Save" : "Salvar",
    "Saving…" : "Salvando...",
    "Group list is empty" : "Lista de grupos vazia",
    "Unable to retrieve the group list" : "Impossível recuperar a lista do grupo",
    "Saved" : "Salvo",
    "Saving failed:" : "A gravação falhou:",
    "Add rule group" : "Adicionar regra do grupo",
    "Example: {placeholder}" : "Examplo: {placeholder}",
    "Select tag…" : "Selecionar etiqueta...",
    "Start" : "Iniciar",
    "End" : "Fim",
    "Select timezone…" : "Selecionar fuso horário...",
    "Sync clients" : "Sincronizar clientes",
    "Workflow" : "Fluxo de trabalho",
    "Files workflow engine" : "Sistema de fluxo de trabalho de arquivos",
    "Open documentation" : "Abrir documentação",
    "Loading…" : "Carregando...",
    "Tag management" : "Gerenciamento de rótulos"
},
"nplurals=2; plural=(n > 1);");
